@@ -5,21 +5,15 @@ use warnings;
 
 use base 'HTML::Widgets::NavMenu::Object';
 
-use base 'Class::Accessor';
-
-__PACKAGE__->mk_accessors(
-    qw(_capture),
+__PACKAGE__->mk_acc_ref([
+    qw(_capture)],
     );
 
 sub _init
 {
-    my $self = shift;
+    my ($self, $args) = @_;
 
-    my %args = (@_);
-
-    my $capture = $args{'capture'};
-
-    $self->_capture($capture);
+    $self->_capture($args->{'capture'});
 
     return 0;
 }
