@@ -7,19 +7,20 @@ use base qw(HTML::Widgets::NavMenu::Iterator::Html);
 
 =head1 NAME
 
-HTML::Widgets::NavMenu::Iterator::Html - an iterator for HTML.
+HTML::Widgets::NavMenu::Iterator::SiteMap - a site-map iterator.
 
 =head1 SYNOPSIS
 
 For internal use only.
 
 =head1 METHODS
+
 =cut
 
 sub _start_root
 {
     my $self = shift;
-    
+
     $self->_add_tags("<ul>");
 }
 
@@ -34,8 +35,6 @@ sub _start_regular
     my $top_item = $self->top;
     my $node = $self->top->_node();
 
-    my $nav_menu = $self->{'nav_menu'};
-
     $self->_add_tags("<li>");
     my $tag = $self->get_a_tag();
     my $title = $node->title();
