@@ -5,8 +5,8 @@ use warnings;
 
 use base 'HTML::Widgets::NavMenu::Object';
 
-__PACKAGE__->mk_accessors(
-    qw(type bool regexp callback capture),
+__PACKAGE__->mk_acc_ref([
+    qw(type bool regexp callback _capture)],
     );
 
 use HTML::Widgets::NavMenu::ExpandVal;
@@ -109,13 +109,14 @@ sub _assign_spec
         die "Neither 'cb' nor 're' nor 'bool' were specified in the spec.";
     }
 
-    $self->capture(
+    $self->_capture(
         (
             (!exists($spec->{capt})) ? 1 : $spec->{capt}
         )
     );
 }
 
+
 sub _evaluate_bool
 {
     my ($self, $args) = @_;
@@ -156,7 +157,7 @@ sub evaluate
     {
         return HTML::Widgets::NavMenu::ExpandVal->new(
             {
-                capture => $self->capture()
+                capture => $self->_capture()
             },
         );
     }
@@ -164,7 +165,7 @@ sub evaluate
 
 =head1 NAME
 
-HTML::Widgets::NavMenu::Predicate - a predicate object for 
+HTML::Widgets::NavMenu::Predicate - a predicate object for
 HTML::Widgets::NavMenu
 
 =head1 SYNOPSIS
@@ -182,6 +183,22 @@ Creates a new object.
 Evaluates the predicate in the context of C<$path_info> and C<$current_host>
 and returns the result.
 
+=head2 $pred->type()
+
+The type of the predicate.
+
+=head2 $pred->bool()
+
+Sets/gets the boolean value in case the type is a boolean.
+
+=head2 $pred->callback()
+
+Sets/gets the callback in case the type is callback.
+
+=head2 $pred->regexp()
+
+Sets/gets the regular expression in case the type is "regexp".
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2006 Shlomi Fish, all rights reserved.
